@@ -2,7 +2,7 @@
 """
     Game Conqueror: a graphical game cheating tool, using scanmem as its backend
     
-    Copyright (C) 2009,2010 Wang Lu <coolwanglu(a)gmail.com>
+    Copyright (C) 2009,2010,2011 Wang Lu <coolwanglu(a)gmail.com>
     Copyright (C) 2010 Bryan Cain
 
     This program is free software: you can redistribute it and/or modify
@@ -164,8 +164,8 @@ class GameConqueror():
         self.scanresult_liststore = gtk.ListStore(str, str, str) 
         self.scanresult_tv.set_model(self.scanresult_liststore)
         # init columns
-        misc.treeview_append_column(self.scanresult_tv, 'Address', attributes=(('text',0),) )
-        misc.treeview_append_column(self.scanresult_tv, 'Value', attributes=(('text',1),) )
+        misc.treeview_append_column(self.scanresult_tv, 'Address', attributes=(('text',0),), properties = (('family', 'monospace'),))
+        misc.treeview_append_column(self.scanresult_tv, 'Value', attributes=(('text',1),), properties = (('family', 'monospace'),))
 
         # init CheatList TreeView
         self.cheatlist_tv = self.builder.get_object('CheatList_TreeView')
@@ -206,6 +206,7 @@ class GameConqueror():
         # Address
         misc.treeview_append_column(self.cheatlist_tv, 'Address'
                                         ,attributes = (('text',3),)
+                                        ,properties = (('family', 'monospace'),)
                                    )
         # Type
         misc.treeview_append_column(self.cheatlist_tv, 'Type'
@@ -222,7 +223,8 @@ class GameConqueror():
         # Value 
         misc.treeview_append_column(self.cheatlist_tv, 'Value'
                                         ,attributes = (('text',5),)
-                                        ,properties = (('editable', True),)
+                                        ,properties = (('editable', True)
+                                                      ,('family', 'monospace'))
                                         ,signals = (('edited', self.cheatlist_edit_value_cb),
                                                     ('editing-started', self.cheatlist_edit_start),
                                                     ('editing-canceled', self.cheatlist_edit_cancel),)
@@ -295,6 +297,7 @@ class GameConqueror():
         self.backend = GameConquerorBackend()
         self.backend.add_error_listener(self.backend_error_cb)
         self.backend.add_progress_listener(self.backend_progress_cb)
+        self.check_backend_version()
         self.search_count = 0
         self.data_worker_id = gobject.timeout_add(DATA_WORKER_INTERVAL, self.data_worker)
         self.command_lock = threading.RLock()
@@ -533,6 +536,9 @@ class GameConqueror():
 
     def cheatlist_edit_value_cb(self, cell, path, new_text, data=None):
         self.cheatlist_editing = False
+        # ignore empty value
+        if new_text == '':
+            return True
         row = int(path)
         self.cheatlist_liststore[row][5] = new_text
         if self.cheatlist_liststore[row][1]: # locked
@@ -585,9 +591,9 @@ class GameConqueror():
         if typename in TYPESIZES.keys(): # int or float type; fixed length
             return TYPESIZES[typename]
         elif typename == 'bytearray':
-            return len(value)
-        elif typename == 'string': # string = characters + one null byte 
-            return len(value) + 1
+            return (len(value.strip())+1)/3
+        elif typename == 'string':
+            return len(eval('\''+value+'\''))
         return None
 
     # parse bytes dumped by scanmem into number, string, etc.
@@ -595,7 +601,9 @@ class GameConqueror():
         if typename in TYPENAMES_G2STRUCT.keys():
             return struct.unpack(TYPENAMES_G2STRUCT[typename], bytes)[0]
         elif typename == 'string':
-            return struct.unpack('%is'%len(bytes), bytes)
+            return repr('%s'%(bytes,))[1:-1]
+        elif typename == 'bytearray':
+            return ' '.join(['%02x'%ord(i) for i in bytes])
         else:
             return bytes
     
@@ -860,7 +868,6 @@ class GameConqueror():
                 if locked:
                     self.write_value(addr, typestr, value)
                 elif i in self.cheatlist_updates:
-                    print 'Adding value for position', i
                     self.write_value(addr, typestr, value)
                     self.cheatlist_updates.remove(i)
                 else:
@@ -911,6 +918,10 @@ class GameConqueror():
     def main(self):
         gtk.main()
 
+    def check_backend_version(self):
+        if self.backend.version != VERSION:
+            self.show_error('Version of scanmem mismatched, you may encounter problems. Please make sure you are using the same version of Gamconqueror as scanmem.')
+
     
 
 if __name__ == '__main__':
