@@ -26,6 +26,7 @@
 
 #include "config.h"
 
+#include <unistd.h>
 #include <stdio.h>
 #include <sys/types.h>
 #include <stdlib.h>
@@ -88,7 +89,7 @@ int main(int argc, char **argv)
             }
             break;
         case 'v':
-            printversion();
+            printversion(stderr);
             return EXIT_SUCCESS;
         case 'h':
             printhelp();
@@ -198,7 +199,20 @@ int main(int argc, char **argv)
                     DEFAULT_LONGDOC);
 
     if (!(globals.options.backend))
-        printversion();
+    {
+        // show welcome message
+        printversion(stderr);
+    }
+    else
+    {
+        // tell front-end our version
+        printf("%s\n", PACKAGE_VERSION); 
+    }
+
+    if (getuid() != 0)
+    {
+        show_error("*** YOU ARE NOT RUNNING scanmem AS ROOT, IT MAY NOT WORK WELL. ***\n\n");
+    }
 
     /* this will initialise matches and regions */
     if (execcommand(vars, "reset") == false) {
@@ -263,7 +277,7 @@ void sighandler(int n)
 /* print quick usage message to stderr */
 void printhelp()
 {
-    printversion();
+    printversion(stderr);
 
     show_user("Usage: scanmem [OPTION]... [PID]\n"
             "Interactively locate and modify variables in an executing process.\n"
